Index: tmp/org.txm.treetagger.core/src/org/txm/importer/xmltxm/AnnotationInjectionFromTTOutput.groovy
===================================================================
--- tmp/org.txm.treetagger.core/src/org/txm/importer/xmltxm/AnnotationInjectionFromTTOutput.groovy	(revision 1204)
+++ tmp/org.txm.treetagger.core/src/org/txm/importer/xmltxm/AnnotationInjectionFromTTOutput.groovy	(revision 1205)
@@ -172,8 +172,7 @@
 	 * Builds the link parsers.
 	 * I need to know what groups exists to build a parser per taxonomy and go to the first link element
 	 */
-	private void buildLinkParsers()
-	{
+	private void buildLinkParsers() {
 		// link group of the standoff file
 		links = findGrpLink();
 		linkparsers = new HashMap<String, XMLStreamReader>();
@@ -191,8 +190,9 @@
 				if (event == XMLStreamConstants.START_ELEMENT) {
 					if (anaparser.getLocalName().equals("linkGrp")) { // position the parser to the right group
 						String targetsvalue = anaparser.getAttributeValue(0)
-						if (targetsvalue.equals(link))
+						if (targetsvalue.equals(link)) {
 							break; // next element is a link start tag
+						}
 					}
 				}
 			}
@@ -205,8 +205,7 @@
 	 * @param link the link
 	 * @return the next ana
 	 */
-	private String getNextAnaValue(String link, String wordId)
-	{
+	private String getNextAnaValue(String link, String wordId) {
 		anaparser = linkparsers.get(link);
 		def m;
 		for (int event = anaparser.next(); event != XMLStreamConstants.END_DOCUMENT; event = anaparser.next()) {
Index: tmp/org.txm.textsbalance.rcp/src/org/txm/textsbalance/rcp/editors/TextsBalanceEditor.java
===================================================================
--- tmp/org.txm.textsbalance.rcp/src/org/txm/textsbalance/rcp/editors/TextsBalanceEditor.java	(revision 1204)
+++ tmp/org.txm.textsbalance.rcp/src/org/txm/textsbalance/rcp/editors/TextsBalanceEditor.java	(revision 1205)
@@ -27,7 +27,7 @@
 	/**
 	 * Group by words.
 	 */
-	protected Button groupByWords;
+	protected Button countWordsButton;
 
 
 	
@@ -66,16 +66,16 @@
 		
 		Group group = new Group(parametersArea, SWT.NONE);
 		
-		group.setText("Group by");
+		group.setText("Count");
 		group.setLayout(new RowLayout());
 		
 		this.groupByTexts = new Button(group, SWT.RADIO);
-		this.groupByTexts.setText("text"); //$NON-NLS-1$
+		this.groupByTexts.setText("texts"); //$NON-NLS-1$
 		this.groupByTexts.setSelection(this.getResult().isGroupByTexts());	
 		
-		this.groupByWords = new Button(group, SWT.RADIO);
-		this.groupByWords.setText("word"); //$NON-NLS-1$
-		this.groupByWords.setSelection(!groupByTexts.getSelection());
+		this.countWordsButton = new Button(group, SWT.RADIO);
+		this.countWordsButton.setText("words"); //$NON-NLS-1$
+		this.countWordsButton.setSelection(!groupByTexts.getSelection());
 
 		
 		// Structural units and properties combo viewers
@@ -89,17 +89,11 @@
 
 		//supCombo.addSelectionListener(listener);
 		groupByTexts.addSelectionListener(new ComputeSelectionListener(this));
-		groupByWords.addSelectionListener(new ComputeSelectionListener(this));
-
+		countWordsButton.addSelectionListener(new ComputeSelectionListener(this));
 	}
 
-
-
-
 	@Override
 	public void updateEditorFromChart(boolean update) {
 		// nothing to do
 	}
-
-
 }
Index: tmp/org.txm.rcp/META-INF/MANIFEST.MF
===================================================================
--- tmp/org.txm.rcp/META-INF/MANIFEST.MF	(revision 1204)
+++ tmp/org.txm.rcp/META-INF/MANIFEST.MF	(revision 1205)
@@ -36,7 +36,8 @@
  org.txm.annotation.core;visibility:=reexport,
  org.eclipse.ui.views;bundle-version="3.9.0";visibility:=reexport,
  org.txm.groovy.core;visibility:=reexport,
- org.txm.treetagger.core;visibility:=reexport
+ org.txm.treetagger.core;visibility:=reexport,
+ org.eclipse.equinox.p2.discovery.compatibility;bundle-version="1.0.201"
 Export-Package: junit.extensions,
  junit.framework,
  junit.runner,
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/RCPPreferences.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/RCPPreferences.java	(revision 1204)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/RCPPreferences.java	(revision 1205)
@@ -54,6 +54,7 @@
 	/** The Constant RIGHT_CONTEXT_SIZE_DEFAULT. */
 	public static final int RIGHT_CONTEXT_SIZE_DEFAULT = 15;
 
+	public static final String UPDATESITE = "update_site"; //$NON-NLS-1$
 	
 	@Override
 	public void initializeDefaultPreferences() {
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/DebugPreferencePage.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/DebugPreferencePage.java	(revision 1204)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/preferences/DebugPreferencePage.java	(revision 1205)
@@ -1,8 +1,8 @@
 package org.txm.rcp.preferences;
 
 import org.eclipse.jface.preference.BooleanFieldEditor;
+import org.eclipse.jface.preference.StringFieldEditor;
 import org.eclipse.ui.IWorkbench;
-import org.eclipse.ui.preferences.ScopedPreferenceStore;
 import org.txm.core.preferences.TBXPreferences;
 import org.txm.rcp.messages.TXMUIMessages;
 import org.txm.rcp.views.corpora.CorporaView;
@@ -20,6 +20,7 @@
 	public void createFieldEditors() {
 		// Show all result nodes in Corpora view
 		addField(new BooleanFieldEditor(TBXPreferences.SHOW_ALL_RESULT_NODES, TXMUIMessages.preferences_advanced_showAllResultNodesInCorporaView, getFieldEditorParent()));
+		addField(new StringFieldEditor(TBXPreferences.UPDATESITE, "Update site addres", getFieldEditorParent()));
 	}
 	
 	
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/p2/plugins/TXMUpdateHandler.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/p2/plugins/TXMUpdateHandler.java	(revision 1204)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/p2/plugins/TXMUpdateHandler.java	(revision 1205)
@@ -42,6 +42,7 @@
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.statushandlers.StatusManager;
 import org.osgi.framework.Version;
+import org.txm.core.preferences.TBXPreferences;
 import org.txm.core.preferences.TXMPreferences;
 import org.txm.rcp.Activator;
 import org.txm.rcp.TxmPreferences;
@@ -54,7 +55,7 @@
 
 public class TXMUpdateHandler extends UpdateHandler {
 
-	public static final String UPDATESITE = "http://textometrie.ens-lyon.fr/dist"; //
+	//public static final String UPDATESITE = "http://textometrie.ens-lyon.fr/dist"; //
 	// "file:"+System.getProperty("user.home")+"/TEMP/updates"; // LOCAL TEST ONLY
 	public static final String ID = "org.txm.rcp.p2.plugins.TXMUpdateHandler";
 
@@ -96,12 +97,12 @@
 			}
 
 			// this is the default repository
-			URL baseURL = new URL(UPDATESITE+"/index.html");
+			URL baseURL = new URL(TBXPreferences.getInstance().getString(TBXPreferences.UPDATESITE)+"/index.html");
 			try {
 				InputStream s = baseURL.openStream();
 				s.close();
 			} catch(Exception e) {
-				System.out.println("Update site is not reachable: "+UPDATESITE+", aborting.");
+				System.out.println("Update site is not reachable: "+baseURL+", aborting.");
 				return false;
 			}
 
@@ -196,7 +197,7 @@
 	public static void addDefaultUpdateSites(IProvisioningAgent agent) {
 		Version v = Activator.getDefault().getBundle().getVersion();
 		String version =  ""+v.getMajor()+"."+v.getMinor()+"."+v.getMicro();
-		String uriBase = UPDATESITE+"/"+version+"/main";
+		String uriBase = TBXPreferences.getInstance().getString(TBXPreferences.UPDATESITE)+"/"+version+"/ext";
 		String uriDefault = uriBase+"/stable";
 		try {
 			URI repoUriDefault = new URI(uriDefault);
@@ -263,7 +264,7 @@
 	public static void addDefaultPluginSites(IProvisioningAgent agent) {
 		Version v = Activator.getDefault().getBundle().getVersion();
 		String version =  ""+v.getMajor()+"."+v.getMinor()+"."+v.getMicro();
-		String uriBase = UPDATESITE+"/"+version+"/ext";
+		String uriBase = TBXPreferences.getInstance().getString(TBXPreferences.UPDATESITE)+"/"+version+"/ext";
 
 		String uriDefault = uriBase+"/stable";
 		try {
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/p2/plugins/InstallPluginHandler.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/p2/plugins/InstallPluginHandler.java	(revision 1204)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/p2/plugins/InstallPluginHandler.java	(revision 1205)
@@ -13,6 +13,7 @@
 import org.eclipse.equinox.p2.ui.LoadMetadataRepositoryJob;
 import org.eclipse.equinox.p2.ui.ProvisioningUI;
 import org.eclipse.jface.wizard.WizardDialog;
+import org.txm.core.preferences.TBXPreferences;
 import org.txm.core.preferences.TXMPreferences;
 import org.txm.rcp.preferences.RCPPreferences;
 import org.txm.utils.logger.Log;
@@ -63,7 +64,7 @@
 			
 			Version v = Activator.getDefault().getBundle().getVersion();
 			String version =  ""+v.getMajor()+"."+v.getMinor()+"."+v.getMicro();
-			String uriBase = TXMUpdateHandler.UPDATESITE+"/"+version+"/ext";
+			String uriBase = TBXPreferences.getInstance().getString(TBXPreferences.UPDATESITE)+"/"+version+"/ext";
 			
 			strategy.addLocation(new URI(uriBase+"/stable")); //$NON-NLS-1$
 			
Index: tmp/org.txm.treetagger.binaries.feature/feature.xml
===================================================================
--- tmp/org.txm.treetagger.binaries.feature/feature.xml	(revision 1204)
+++ tmp/org.txm.treetagger.binaries.feature/feature.xml	(revision 1205)
@@ -6,15 +6,65 @@
       provider-name="Textometrie.org">
 
    <description url="http://www.example.com/description">
-      [Enter Feature Description here.]
+      Install TreeTagger / Installation TreeTagger
    </description>
 
-   <copyright url="http://www.example.com/copyright">
-      [Enter Copyright Description here.]
+   <copyright url="http://www.cis.uni-muenchen.de/~schmid/tools/TreeTagger/">
+      See: http://www.cis.uni-muenchen.de/~schmid/tools/TreeTagger/
    </copyright>
 
-   <license url="http://www.example.com/license">
-      [Enter License Description here.]
+   <license url="http://www.cis.uni-muenchen.de/~schmid/tools/TreeTagger/Tagger-Licence">
+      ** TreeTagger License **
+
+1. The Institut fuer maschinelle Sprachverarbeitung, Universitaet
+   Stuttgart, subsequently called ``the licenser&apos;&apos;, grants you (the
+   licensee) the rights to use the TreeTagger software subsequently
+   called ``the system&apos;&apos; for evaluation, research and teaching
+   purposes. **Any other usage of the system (in particular for
+   commercial purposes) is forbidden**.
+
+2. The licensee has no right to give or sell the system to third
+   parties without written permission from the licenser.
+
+3. The licenser has no obligation to maintain the system.
+   Nevertheless the licensee is encouraged to report to the licenser
+   any problems with or suggestions for improvement of the system.
+
+4. The licenser has no obligation to make new releases available to the
+   licensee, but where such updates are supplied they shall be governed by
+   the terms of this agreement.
+
+      NO WARRANTY
+
+5. BECAUSE THE SYSTEM IS LICENSED FREE OF CHARGE, WE PROVIDE
+ABSOLUTELY NO WARRANTY, TO THE EXTENT PERMITTED BY APPLICABLE STATE
+LAW. EXCEPT WHEN OTHERWISE STATED IN WRITING THE LICENSER PROVIDES THE
+SYSTEM &quot;AS IS&quot; WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR
+IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
+MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE ENTIRE RISK
+AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS WITH THE LICENSEE.
+SHOULD THE SYSTEM PROVE DEFECTIVE, THE LICENSEE ASSUMES THE COST OF
+ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
+
+6. IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW WILL THE LICENSER BE
+LIABLE TO THE LICENSEE FOR DAMAGES, INCLUDING ANY LOST PROFITS, LOST
+MONIES, OR OTHER SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES ARISING
+OUT OF THE USE OR INABILITY TO USE (INCLUDING BUT NOT LIMITED TO LOSS
+OF DATA OR DATA BEING RENDERED INACCURATE OR LOSSES SUSTAINED BY THIRD
+PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAM)
+THE PROGRAM, EVEN IF THE LICENSEE HAS BEEN ADVISED OF THE POSSIBILITY
+OF SUCH DAMAGES, OR FOR ANY CLAIM BY ANY OTHER PARTY.
+
+
+Contact Adress:
+
+Helmut Schmid
+Institut fuer maschinelle Sprachverarbeitung (IMS) 
+Universitaet Stuttgart
+Azenbergstr. 12
+D-70174 Stuttgart, Germany
+
+Helmut.Schmid@ims.uni-stuttgart.de
    </license>
 
    <plugin
@@ -24,8 +74,7 @@
          download-size="0"
          install-size="0"
          version="0.0.0"
-         fragment="true"
-         unpack="false"/>
+         fragment="true"/>
 
    <plugin
          id="org.txm.treetagger.core.macosx"
@@ -34,8 +83,7 @@
          download-size="0"
          install-size="0"
          version="0.0.0"
-         fragment="true"
-         unpack="false"/>
+         fragment="true"/>
 
    <plugin
          id="org.txm.treetagger.core.win32"
@@ -44,7 +92,6 @@
          download-size="0"
          install-size="0"
          version="0.0.0"
-         fragment="true"
-         unpack="false"/>
+         fragment="true"/>
 
 </feature>
Index: tmp/org.txm.treetagger.files.feature/feature.xml
===================================================================
--- tmp/org.txm.treetagger.files.feature/feature.xml	(revision 1204)
+++ tmp/org.txm.treetagger.files.feature/feature.xml	(revision 1205)
@@ -6,8 +6,7 @@
       provider-name="Textometrie.org">
 
    <description>
-      Install TreeTagger for TXM.&lt;br/&gt;
-See http://www.cis.uni-muenchen.de/~schmid/tools/TreeTagger for more informations about TreeTagger.
+      FR and EN TreeTagger models / Modèles FR et EN de TreeTagger
    </description>
 
    <copyright url="http://www.cis.uni-muenchen.de/~schmid/tools/TreeTagger/">
Index: tmp/org.txm.core/src/java/org/txm/importer/scripts/xmltxm/AnnotationInjection.groovy
===================================================================
--- tmp/org.txm.core/src/java/org/txm/importer/scripts/xmltxm/AnnotationInjection.groovy	(revision 1204)
+++ tmp/org.txm.core/src/java/org/txm/importer/scripts/xmltxm/AnnotationInjection.groovy	(revision 1205)
@@ -186,8 +186,8 @@
 	 * Builds the link parsers.
 	 * I need to know what groups exists to build a parser per taxonomy and go to the first link element
 	 */
-	private void buildLinkParsers()
-	{
+	private void buildLinkParsers() {
+		
 		// link group of the standoff file
 		links = findGrpLink();
 		linkparsers = new LinkedHashMap<String, XMLStreamReader>();
@@ -205,8 +205,9 @@
 				if (event == XMLStreamConstants.START_ELEMENT) {
 					if (anaparser.getLocalName().equals("linkGrp")) { // position the parser to the right group
 						String targetsvalue = anaparser.getAttributeValue(0)
-						if (targetsvalue.equals(link))
+						if (targetsvalue.equals(link)) {
 							break; // next element is a link start tag
+						}
 					}
 				}
 			}
@@ -219,8 +220,7 @@
 	 * @param link the link
 	 * @return the next ana
 	 */
-	private String getNextAnaValue(String link, String wordId)
-	{
+	private String getNextAnaValue(String link, String wordId) {
 		anaparser = linkparsers.get(link);
 		def m;
 		for (int event = anaparser.next(); event != XMLStreamConstants.END_DOCUMENT; event = anaparser.next()) {
@@ -274,8 +274,8 @@
 	HashMap<String, String> anaValues = new HashMap<String, String>();
 	boolean flagSourceDesc = false, flagW = false, flagAna = false;
 	String type = null, resp = null, anaValue= "";
-	protected void processStartElement()
-	{
+	protected void processStartElement() {
+		
 		if (localname.equals("taxonomy")) {
 			String taxo = parser.getAttributeValue(0) // taxonomy type
 			presentTaxonomies.add(taxo);
@@ -311,7 +311,7 @@
 	protected void processCharacters() {
 		if (flagAna) anaValue += parser.getText();
 		else super.processCharacters(); // FORM CONTENT LOST !!!!!!!!!!!!!
-	};
+	}
 
 	boolean applicationWritten = false;
 	boolean taxonomiesWritten = false;
Index: tmp/org.txm.core/src/java/org/txm/Toolbox.java
===================================================================
--- tmp/org.txm.core/src/java/org/txm/Toolbox.java	(revision 1204)
+++ tmp/org.txm.core/src/java/org/txm/Toolbox.java	(revision 1205)
@@ -558,6 +558,14 @@
 
 	private static boolean startWorkspace(IProgressMonitor monitor) {
 		
+//		System.out.println("STARRTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT");
+//		System.out.println("STARRTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT");
+//		System.out.println("STARRTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT");
+//		System.out.println("STARRTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT");
+//		System.out.println("STARRTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT");
+//		System.out.println("STARRTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT");
+//		System.out.println("STARRTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT");
+//		System.out.println("STARRTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT");
 		String txmhomedir = getPreference(TBXPreferences.USER_TXM_HOME);
 		if (txmhomedir == null || txmhomedir.length() == 0) {
 			state = false;
Index: tmp/org.txm.core/src/java/org/txm/core/preferences/TBXPreferences.java
===================================================================
--- tmp/org.txm.core/src/java/org/txm/core/preferences/TBXPreferences.java	(revision 1204)
+++ tmp/org.txm.core/src/java/org/txm/core/preferences/TBXPreferences.java	(revision 1205)
@@ -62,6 +62,7 @@
 	 * To show or not all nodes in some views, eg. in CorporaView tree.
 	 */
 	public static final String SHOW_ALL_RESULT_NODES = "show_all_result_nodes"; //$NON-NLS-1$
+	public static final String UPDATESITE = "update_site"; //$NON-NLS-1$
 	
 	
 	/**
@@ -171,5 +172,11 @@
 		
 		preferences.putBoolean(SHOW_ALL_RESULT_NODES, false);
 		preferences.putBoolean(AUTO_PERSISTENCE_ENABLED, false);
+		
+		if (Toolbox.getTxmHomePath().endsWith("-dev")) {
+			preferences.put(UPDATESITE, "file:///"+System.getProperty("user.home")+"/workspace047/TXMReleasePlugins.site");
+		} else {
+			preferences.put(UPDATESITE, "http://textometrie.ens-lyon.fr/dist");
+		}
 	}
 }
Index: tmp/org.txm.rcp.feature/feature.xml
===================================================================
--- tmp/org.txm.rcp.feature/feature.xml	(revision 1204)
+++ tmp/org.txm.rcp.feature/feature.xml	(revision 1205)
@@ -250,6 +250,7 @@
       <import plugin="org.txm.chartsengine.core" version="1.0.0" match="greaterOrEqual"/>
       <import plugin="org.txm.groovy.core"/>
       <import plugin="org.txm.treetagger.core"/>
+      <import plugin="org.txm.treetagger.rcp"/>
       <import plugin="javax.persistence" version="2.1.0" match="greaterOrEqual"/>
       <import plugin="org.eclipse.persistence.jpa" version="2.6.0" match="greaterOrEqual"/>
       <import plugin="org.eclipse.persistence.jpa.jpql" version="2.6.0" match="greaterOrEqual"/>
Index: tmp/org.txm.ahc.core/META-INF/MANIFEST.MF
===================================================================
--- tmp/org.txm.ahc.core/META-INF/MANIFEST.MF	(revision 1204)
+++ tmp/org.txm.ahc.core/META-INF/MANIFEST.MF	(revision 1205)
@@ -10,4 +10,3 @@
 Bundle-ManifestVersion: 2
 Bundle-SymbolicName: org.txm.ahc.core;singleton:=true
 Bundle-RequiredExecutionEnvironment: JavaSE-1.7
-

Index: tmp/org.txm.textsbalance.core/src/org/txm/textsbalance/core/functions/TextsBalance.java
===================================================================
--- tmp/org.txm.textsbalance.core/src/org/txm/textsbalance/core/functions/TextsBalance.java	(revision 1204)
+++ tmp/org.txm.textsbalance.core/src/org/txm/textsbalance/core/functions/TextsBalance.java	(revision 1205)
@@ -62,7 +62,7 @@
 	 * Group by texts or not.
 	 */
 	@Parameter(key=TextsBalancePreferences.GROUP_BY_TEXTS)
-	protected boolean groupByTexts;
+	protected boolean countTexts;
 	
 
 	/**
@@ -102,7 +102,7 @@
 	 * @param method
 	 * @param su
 	 * @param suPropertyName
-	 * @param groupByTexts
+	 * @param countTexts
 	 */
 	public void setParameters(StructuralUnit su, StructuralUnitProperty sup) {
 		this.structuralUnit = su;
@@ -122,12 +122,12 @@
 	 * @param method
 	 * @param structuralUnit
 	 * @param suPropertyName
-	 * @param groupByTexts
+	 * @param countTexts
 	 * @throws CqiClientException
 	 */
 	protected boolean _compute() {
 		
-		this.subTask("Computing balance with metadata propertyName = " + this.structuralUnitProperty + ", structural unit = " + this.structuralUnit.getName() + " and groupByTexts = " + this.groupByTexts); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+		this.subTask("Computing balance with metadata propertyName = " + this.structuralUnitProperty + ", structural unit = " + this.structuralUnit.getName() + " and groupByTexts = " + this.countTexts); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
 		try {
 			this.dataset = new HashMap<Integer, Comparable[]>();
 			
@@ -139,7 +139,7 @@
 			if (this.method == 1) {
 				for (String value : this.values) {
 					int v = 0;
-					if (this.groupByTexts) {
+					if (this.countTexts) {
 						QueryResult r = this.getCorpus().query(new CQLQuery("<"+p.getFullName()+"=\""+value+"\">[]"), "tmp", false);
 						v = r.getNMatch();
 						r.drop();
@@ -191,7 +191,7 @@
 				//System.out.println( " with values: "+Arrays.toString(inter_values));
 				HashMap<String, Integer> interUniq = new HashMap<String, Integer>();
 
-				if (this.groupByTexts) {
+				if (this.countTexts) {
 					for (String o : interValues) {
 						if (!interUniq.containsKey(o)) {
 							interUniq.put(o, 0);
@@ -336,7 +336,7 @@
 
 	@Override
 	public String getSimpleName() {
-		return 	this.structuralUnit.getName() + "@" + this.structuralUnitProperty + " (group by texts = " + this.groupByTexts + ")";
+		return 	this.structuralUnit.getName() + "@" + this.structuralUnitProperty + " (group by texts = " + this.countTexts + ")";
 	}
 
 	@Override
@@ -374,7 +374,7 @@
 	 * @return the groupByTexts
 	 */
 	public boolean groupingByTexts() {
-		return groupByTexts;
+		return countTexts;
 	}
 
 
@@ -399,15 +399,15 @@
 	 * @return the groupByTexts
 	 */
 	public boolean isGroupByTexts() {
-		return groupByTexts;
+		return countTexts;
 	}
 
 
 	/**
 	 * @param groupByTexts the groupByTexts to set
 	 */
-	public void setGroupByTexts(boolean groupByTexts) {
-		this.groupByTexts = groupByTexts;
+	public void setDoCountTexts(boolean countTexts) {
+		this.countTexts = countTexts;
 	}
 
 
@@ -399,15 +399,15 @@
 
 	/**
-	 * @param groupByTexts the groupByTexts to set
+	 * @param countTexts the groupByTexts to set
 	 */